#[repr(u8)]pub enum Sharedwssel {
Flexcomm0 = 0,
Flexcomm1 = 1,
Flexcomm2 = 2,
Flexcomm3 = 3,
Flexcomm4 = 4,
Flexcomm5 = 5,
Flexcomm6 = 6,
Flexcomm7 = 7,
}Variants
Flexcomm0 = 0
WS for this shared signal set comes from Flexcomm 0.
Flexcomm1 = 1
WS for this shared signal set comes from Flexcomm 1.
Flexcomm2 = 2
WS for this shared signal set comes from Flexcomm 2.
Flexcomm3 = 3
WS for this shared signal set comes from Flexcomm 3.
Flexcomm4 = 4
WS for this shared signal set comes from Flexcomm 4.
Flexcomm5 = 5
WS for this shared signal set comes from Flexcomm 5.
Flexcomm6 = 6
WS for this shared signal set comes from Flexcomm 6.
Flexcomm7 = 7
WS for this shared signal set comes from Flexcomm 7.
Implementations